**Pyekfmm**
======

## Description

**Pyekfmm** is an eikonal solver using the fast marching method.


## Reference
    Chen et al. (2023). Pyekfmm: a python package for 3D traveltime calculation based on the fast marching method. in preparation
    
BibTeX:

	@article{pyekfmm,
	  title={Pyekfmm: a python package for 3D traveltime calculation based on the fast marching method},
	  author={Chen et al.},
	  journal={TBD},
	  volume={TBD},
	  number={TBD},
	  issue={TBD},
	  pages={in preparation},
	  year={2023}
 	}

-----------
## Copyright
    pyekfmm developing team, 2021-present
-----------

## License
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)   

-----------

## Install
Using the latest version

    git clone https://github.com/chenyk1990/pyekfmm
    cd pyekfmm
    pip install -v -e .
or using Pypi

    pip install pyekfmm

-----------
## Examples
    The "demo" directory contains all runable scripts to demonstrate different applications of pyekfmm. 
    
-----------
## Gallery
The gallery figures of the pyekfmm package can be found at
    https://github.com/chenyk1990/gallery/tree/main/pyekfmm
Each figure in the gallery directory corresponds to a DEMO script in the "demo" directory with the exactly the same file name.

-----------
## Dependence Packages
* scipy 
* numpy 
* matplotlib

-----------
## Development
    The development team welcomes voluntary contributions from any open-source enthusiast. 
    If you want to make contribution to this project, feel free to contact the development team. 

-----------
## Contact
    Regarding any questions, bugs, developments, collaborations, please contact  
    Yangkang Chen
    chenyk2016@gmail.com

-----------


